@@ -551,16 +551,6 @@ indicate_indicator_get_property_value (IndicateIndicator * indicator, const gcha
 	return class->get_property(indicator, key);
 }
 
-/**
-	indicate_indicator_list_properties:
-	@indicator: a #IndicateIndicator to act on
-
-	This function gets a list of all the properties that exist
-	on a @indicator.  The array may have zero entries.
-
-	Return value: An array of strings that is the keys of all
-		the properties on this indicator.
-*/
 GPtrArray *
 indicate_indicator_list_properties (IndicateIndicator * indicator)
 {
