@@ -87,6 +87,46 @@ struct _IndicateServer {
 
 #include "indicator.h"
 
+/**
+ * indicate_server_get_indicator_list_slot_t:
+ * @server: (in): Indicator server to query
+ * @indicators: (out) (transfer container) (array) (element-type Indicator): The indicators which are visible on this server
+ * @error: An error if #FALSE was returned
+ *
+ * Gets the list of indicators that are visible for this server.
+ *
+ * Return value: Whether the call was successful in getting the
+ * list of values in @indicators.
+ */
+typedef gboolean (*indicate_server_get_indicator_list_slot_t) (IndicateServer * server, GArray ** indicators, GError ** error);
+
+/**
+ * indicate_server_get_indicator_property_group_slot_t:
+ * @server: (in): Indicator server to query
+ * @properties: (in) (array) (element-type utf8): Property names that you'd like to get values to.
+ * @value: (out) (transfer full) (array) (element-type utf8): An array of arrays.  Needs more typing.
+ * @error: An error if #FALSE was returned
+ *
+ * Gets the list of indicators that are visible for this server.
+ *
+ * Return value: Whether the call was successful in getting the
+ * properties requested.
+ */
+typedef gboolean (*indicate_server_get_indicator_property_group_slot_t) (IndicateServer * server, guint id, GPtrArray * properties, gchar *** value, GError **error);
+
+/**
+ * indicate_server_get_indicator_properties_slot_t:
+ * @server: (in): Indicator server to query
+ * @properties: (out) (array) (element-type utf8): Property names that are on this indicator.
+ * @error: An error if #FALSE was returned
+ *
+ * Gets the list of indicators that are visible for this server.
+ *
+ * Return value: Whether the call was successful in getting the
+ * property names.
+ */
+typedef gboolean (*indicate_server_get_indicator_properties_slot_t) (IndicateServer * server, guint id, gchar *** properties, GError **error);
+
 /**
 	IndicateServerClass:
 	@parent: Parent Class
@@ -151,10 +191,10 @@ struct _IndicateServerClass {
 
 	/* Virtual Functions */
 	gboolean (*get_indicator_count) (IndicateServer * server, guint * count, GError **error);
-	gboolean (*get_indicator_list) (IndicateServer * server, GArray ** indicators, GError ** error);
+	indicate_server_get_indicator_list_slot_t get_indicator_list;
 	gboolean (*get_indicator_property) (IndicateServer * server, guint id, gchar * property, GValue * value, GError **error);
-	gboolean (*get_indicator_property_group) (IndicateServer * server, guint id, GPtrArray * properties, gchar *** value, GError **error);
-	gboolean (*get_indicator_properties) (IndicateServer * server, guint id, gchar *** properties, GError **error);
+	indicate_server_get_indicator_property_group_slot_t get_indicator_property_group;
+	indicate_server_get_indicator_properties_slot_t get_indicator_properties;
 	gboolean (*show_indicator_to_user) (IndicateServer * server, guint id, guint timestamp, GError ** error);
 	gboolean (*indicator_displayed) (IndicateServer * server, gchar * sender, guint id, gboolean displayed, GError ** error);
 	guint    (*get_next_id) (IndicateServer * server);
